<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * The main salaviva configuration form
 *
 * It uses the standard core Moodle formslib. For more info about them, please
 * visit: http://docs.moodle.org/en/Development:lib/formslib.php
 *
 * @package    mod_salaviva
 * @copyright  2018 NEAD - UPE <fabio.arruda@upe.br>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

require_once($CFG->dirroot.'/course/moodleform_mod.php');

/**
 * Module instance settings form
 *
 * @package    mod_salaviva
 * @copyright  2018 NEAD - UPE <fabio.arruda@upe.br>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class mod_salaviva_mod_form extends moodleform_mod {

    /**
     * Defines forms elements
     */
    public function definition() {
        global $CFG;

        //$servers = array( 0 => get_string('nead/upe'), 1 => get_string('server2'));

        $servers = array("nead/upe", "server2", "server3");
        $roomtypes = array("Sala Viva", "Webconferência");

        $mform = $this->_form;

        // Adding the "general" fieldset, where all the common settings are showed.
        $mform->addElement('header', 'general', get_string('general', 'form'));

        // Adding the standard "name" field.
        $mform->addElement('text', 'name', get_string('salavivaname', 'salaviva'), array('size' => '64'));
        if (!empty($CFG->formatstringstriptags)) {
            $mform->setType('name', PARAM_TEXT);
        } else {
            $mform->setType('name', PARAM_CLEANHTML);
        }
        $mform->addRule('name', null, 'required', null, 'client');
        $mform->addRule('name', get_string('maximumchars', '', 255), 'maxlength', 255, 'client');
        $mform->addHelpButton('name', 'salavivaname', 'salaviva');

        // Adding the standard "intro" and "introformat" fields.
        if ($CFG->branch >= 29) {
            $this->standard_intro_elements();
        } else {
            $this->add_intro_editor();
        }

        // Adding the rest of salaviva settings, spreading all them into this fieldset
        // ... or adding more fieldsets ('header' elements) if needed for better logic.

        //Server field
        $mform->addElement('select', 'server', get_string('server', 'salaviva'), $servers);

        //Room type field
        $mform->addElement('select', 'roomtype', get_string('roomtype', 'salaviva'), $roomtypes);

        //QR Code
        $mform->addElement('header', 'qrcode', get_string('qrcode', 'salaviva'));
        $mform->addElement('checkbox', 'showqrcode', get_string('showqrcode', 'salaviva'));

        // Add standard grading elements.
        //$this->standard_grading_coursemodule_elements();

        // Add appearence elements
        $displayoptions = array("Automático", "Embed", "Abrir", "Em uma janela pop-up");
        $mform->addElement('header', 'display', get_string('display', 'salaviva'));
        $mform->addElement('select', 'displayoptions', get_string('displayoptions', 'salaviva'), $displayoptions);
        $mform->addElement('text', 'displaywidth', get_string('displaywidth', 'salaviva'));
        $mform->addElement('text', 'displayheight', get_string('displayheight', 'salaviva'));

        // Add standard elements, common to all modules.
        $this->standard_coursemodule_elements();

        // Add standard buttons, common to all modules.
        $this->add_action_buttons();
    }
}
