<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Prints a particular instance of salaviva
 *
 * You can have a rather longer description of the file as well,
 * if you like, and it can span multiple lines.
 *
 * @package    mod_salaviva
 * @copyright  2018 NEAD - UPE <fabio.arruda@upe.br>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


require_once(dirname(dirname(dirname(__FILE__))).'/config.php');
require_once(dirname(__FILE__).'/lib.php');

$id = optional_param('id', 0, PARAM_INT); // Course_module ID, or
$n  = optional_param('n', 0, PARAM_INT);  // ... salaviva instance ID - it should be named as the first character of the module.

if ($id) {
    $cm         = get_coursemodule_from_id('salaviva', $id, 0, false, MUST_EXIST);
    $course     = $DB->get_record('course', array('id' => $cm->course), '*', MUST_EXIST);
    $salaviva  = $DB->get_record('salaviva', array('id' => $cm->instance), '*', MUST_EXIST);
} else if ($n) {
    $salaviva  = $DB->get_record('salaviva', array('id' => $n), '*', MUST_EXIST);
    $course     = $DB->get_record('course', array('id' => $salaviva->course), '*', MUST_EXIST);
    $cm         = get_coursemodule_from_instance('salaviva', $salaviva->id, $course->id, false, MUST_EXIST);
} else {
    error('You must specify a course_module ID or an instance ID');
}

require_login($course, true, $cm);

$event = \mod_salaviva\event\course_module_viewed::create(array(
    'objectid' => $PAGE->cm->instance,
    'context' => $PAGE->context,
));
$event->add_record_snapshot('course', $PAGE->course);
$event->add_record_snapshot($PAGE->cm->modname, $salaviva);
$event->trigger();

//Verify room type for url
if($salaviva->roomtype == "0"){
    $roomtypeurl = 'salaviva';
}else if($salaviva->roomtype == "1"){
    $roomtypeurl = 'webconferencia';
}
// Print the page header.

$PAGE->set_url('/mod/salaviva/view.php', array('id' => $cm->id), $roomtypeurl);
$PAGE->set_title(format_string($salaviva->name));
$PAGE->set_heading(format_string($course->fullname));
$PAGE->set_pagelayout('standard');

/*
 * Other things you may want to set - remove if not needed.
 * $PAGE->set_cacheable(false);
 * $PAGE->set_focuscontrol('some-html-id');
 * $PAGE->add_body_class('salaviva-'.$somevar);
 */

if (($edit != -1) and $PAGE->user_allowed_editing()) {
     $USER->editing = $edit;
}
/*
// Add block editing button
if ($PAGE->user_allowed_editing()) {
    $editvalue = $PAGE->user_is_editing() ? 'off' : 'on';
    $strsubmit = $PAGE->user_is_editing() ? get_string('blockseditoff') : get_string('blocksediton');
    $url = new moodle_url($CFG->wwwroot . '/mod/salaviva/view.php', array('id' => $cm->id, 'edit' => $editvalue));
    $PAGE->set_button($OUTPUT->single_button($url, $strsubmit));
}
*/
// Output starts here.
echo $OUTPUT->header();

//Show name
echo $OUTPUT->heading(format_string($salaviva->name));

// Conditions to show the intro can change to look for own settings or whatever.
if ($salaviva->intro) {
    echo $OUTPUT->box(format_module_intro('salaviva', $salaviva, $cm->id), 'generalbox mod_introbox', 'salavivaintro');
}

//Show roomtype

if($salaviva->server == "0"){
    $findserver = "nead/upe";
}
if($salaviva->server == "1"){
    $findserver = "servidor 2";
}
if($salaviva->server == "2"){
    $findserver = "servidor 3";
}

if($salaviva->roomtype == "0"){
    $findroomtype = "Sala Viva";
}else if($salaviva->roomtype == "1"){
    $findroomtype = "Webconferência";
}

if($salaviva->displayoptions == "0"){
    $finddisplayoption = "Automático";
}
if($salaviva->displayoptions == "1"){
    $finddisplayoption = "Embed";
}
if($salaviva->displayoptions == "2"){
    $finddisplayoption = "Abrir";
}
if($salaviva->displayoptions == "3"){
    $finddisplayoption = "Em uma janela pop-up";
}

//$url = new moodle_url($CFG->wwwroot . '/mod/salaviva/view.php', array('id' => $cm->id);
//$url = $this->page->url;
$url = $PAGE->url;
$urlqrcode = "https://chart.googleapis.com/chart?chs=150x150&cht=qr&chl=" . $url;

echo $OUTPUT->box(format_string("Tipo de Sala: ". $findroomtype));
echo $OUTPUT->box(format_string("Servidor: " . $findserver));
echo $OUTPUT->box(format_string("Exibir: " . $finddisplayoption));
echo $OUTPUT->box(format_string("QR Code: "));

if($salaviva->showqrcode == "1"){
    echo "<img src='$urlqrcode' />";
}


// Finish the page.
echo $OUTPUT->footer();
